=============================
Django EL(Endless) Pagination
=============================

This application provides Twitter- and Digg-style pagination, with multiple
and lazy pagination and optional Ajax support. It is devoted to implementing
web pagination in very few steps.

The **source code** for this app is hosted at
https://github.com/shtalinberg/django-el-pagination.

:doc:`start` is easy!

Contents:

.. toctree::
   :maxdepth: 2

   changelog
   start
   twitter_pagination
   digg_pagination
   multiple_pagination
   lazy_pagination
   different_first_page
   current_page_number
   templatetags_reference
   javascript
   generic_views
   customization
   contributing
   contacts
   thanks
